==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/SelectFromInstancesSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.component.InstancePopulationSelectorSet;
import io.ciera.tool.sql.architecture.component.impl.InstancePopulationSelectorSetImpl;
import io.ciera.tool.sql.architecture.expression.SelectFromInstances;
import io.ciera.tool.sql.architecture.expression.SelectFromInstancesSet;
import io.ciera.tool.sql.architecture.expression.SelectSet;
import io.ciera.tool.sql.architecture.expression.impl.SelectSetImpl;

import java.util.Arrays;
import java.util.List;


public class SelectFromInstancesSetImpl extends InstanceSet<SelectFromInstancesSet,SelectFromInstances> implements SelectFromInstancesSet {

    // attributes
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setStatement_number( ref_statement_number );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setBody_name( ref_body_name );
    }
    @Override
    public void setSelector_comp_package( String ref_selector_comp_package ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setSelector_comp_package( ref_selector_comp_package );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setExpression_number( ref_expression_number );
    }
    @Override
    public void setSelector_comp_name( String ref_selector_comp_name ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setSelector_comp_name( ref_selector_comp_name );
    }
    @Override
    public void setSelector_name( String ref_selector_name ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setSelector_name( ref_selector_name );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setParent_name( ref_parent_name );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setParent_package( ref_parent_package );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setBlock_number( ref_block_number );
    }


    // selections
    @Override
    public SelectSet R789_is_a_Select() throws XtumlException {
        SelectSet selectset = new SelectSetImpl();
        for ( SelectFromInstances selectfrominstances : this ) selectset.add( selectfrominstances.R789_is_a_Select() );
        return selectset;
    }
    @Override
    public InstancePopulationSelectorSet R799_selects_instances_through_InstancePopulationSelector() throws XtumlException {
        InstancePopulationSelectorSet instancepopulationselectorset = new InstancePopulationSelectorSetImpl();
        for ( SelectFromInstances selectfrominstances : this ) instancepopulationselectorset.add( selectfrominstances.R799_selects_instances_through_InstancePopulationSelector() );
        return instancepopulationselectorset;
    }


    @Override
    public SelectFromInstances nullElement() {
        return SelectFromInstancesImpl.EMPTY_SELECTFROMINSTANCES;
    }

    @Override
    public SelectFromInstancesSet emptySet() {
      return new SelectFromInstancesSetImpl();
    }

    @Override
    public SelectFromInstancesSet value() {
        return this;
    }

    @Override
    public List<SelectFromInstances> elements() {
        return Arrays.asList(toArray(new SelectFromInstances[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/SelectFromInstancesSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.component.InstancePopulationSelectorSet;
import io.ciera.tool.sql.architecture.component.impl.InstancePopulationSelectorSetImpl;
import io.ciera.tool.sql.architecture.expression.SelectFromInstances;
import io.ciera.tool.sql.architecture.expression.SelectFromInstancesSet;
import io.ciera.tool.sql.architecture.expression.SelectSet;
import io.ciera.tool.sql.architecture.expression.impl.SelectSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SelectFromInstancesSetImpl extends InstanceSet<SelectFromInstancesSet,SelectFromInstances> implements SelectFromInstancesSet {

    public SelectFromInstancesSetImpl() {
    }

    public SelectFromInstancesSetImpl(Comparator<? super SelectFromInstances> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setBody_name( ref_body_name );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setParent_package( ref_parent_package );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setParent_name( ref_parent_name );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setStatement_number( ref_statement_number );
    }
    @Override
    public void setSelector_comp_package( String ref_selector_comp_package ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setSelector_comp_package( ref_selector_comp_package );
    }
    @Override
    public void setSelector_comp_name( String ref_selector_comp_name ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setSelector_comp_name( ref_selector_comp_name );
    }
    @Override
    public void setSelector_name( String ref_selector_name ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setSelector_name( ref_selector_name );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setBlock_number( ref_block_number );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( SelectFromInstances selectfrominstances : this ) selectfrominstances.setExpression_number( ref_expression_number );
    }


    // selections
    @Override
    public SelectSet R789_is_a_Select() throws XtumlException {
        SelectSet selectset = new SelectSetImpl();
        for ( SelectFromInstances selectfrominstances : this ) selectset.add( selectfrominstances.R789_is_a_Select() );
        return selectset;
    }
    @Override
    public InstancePopulationSelectorSet R799_selects_instances_through_InstancePopulationSelector() throws XtumlException {
        InstancePopulationSelectorSet instancepopulationselectorset = new InstancePopulationSelectorSetImpl();
        for ( SelectFromInstances selectfrominstances : this ) instancepopulationselectorset.add( selectfrominstances.R799_selects_instances_through_InstancePopulationSelector() );
        return instancepopulationselectorset;
    }


    @Override
    public SelectFromInstances nullElement() {
        return SelectFromInstancesImpl.EMPTY_SELECTFROMINSTANCES;
    }

    @Override
    public SelectFromInstancesSet emptySet() {
      return new SelectFromInstancesSetImpl();
    }

    @Override
    public SelectFromInstancesSet emptySet(Comparator<? super SelectFromInstances> comp) {
      return new SelectFromInstancesSetImpl(comp);
    }

    @Override
    public SelectFromInstancesSet value() {
        return this;
    }

    @Override
    public List<SelectFromInstances> elements() {
        return Arrays.asList(toArray(new SelectFromInstances[0]));
    }

}
